Derive Macro rustler_codegen::NifRecord [−][src]
#[derive(NifRecord)]
{
// Attributes available to this derive:
#[tag]
#[rustler]
}
Implementation of the NifRecord macro that lets the user annotate a struct that will
be translated directly from an Elixir struct to a Rust struct. For example, the following
struct, annotated as such:
ⓘ
#[derive(Debug, NifRecord)] #[tag = "record"] struct AddRecord { lhs: i32, rhs: i32, }
This would be translated by Rustler into:
defmodule AddRecord do
import Record
defrecord :record, [lhs: 1, rhs: 2]
end